.. libEnsemble documentation master file for the latex build

=====
Dummy
=====

.. toctree::
   :maxdepth: 3

   Introduction<introduction_latex>
   programming_libE
   running_libE
   platforms/platforms_index

Developer's Guide
=================

This section contains further information for those interested in adding
features to libEnsemble.

.. toctree::
   :maxdepth: 3

   contributing
   dev_guide/dev_API/developer_API.rst
   dev_guide/release_management/release_index.rst

Appendices
==========

This section contains tutorials, frequently asked questions, examples, and
other libEnsemble information.

.. toctree::
   :maxdepth: 3

   advanced_installation
   tutorials/tutorials
   FAQ
   known_issues
   examples/examples_index
   release_notes

.. bibliography:: references.bib
